@@ -1,4 +1,3 @@
-
 """
     pyexcel.io
     ~~~~~~~~~~~~~~~~~~~
@@ -8,27 +7,33 @@
     :copyright: (c) 2014 by C. W.
     :license: GPL v3
 """
+from functools import partial
 from .csvbook import CSVBook, CSVWriter
-from .xlbook import XLBook, XLWriter
-from ..sheets import is_string
+from .._compact import is_string
+
 
 # A list of registered readers
 READERS = {
-    "xls": XLBook,
-    "xlsm": XLBook,
-    "xlsx": XLBook,
     "csv": CSVBook,
+    "tsv": partial(CSVBook, dialect="excel-tab")
 }
 
 
 # A list of registered writers
 WRITERS = {
-    "xls": XLWriter,
-    "xlsm": XLWriter,
-    "xlsx": XLWriter,
     "csv": CSVWriter,
+    "tsv": partial(CSVWriter, dialect="excel-tab")
 }
 
+def list_readers():
+    """list available readers"""
+    print(READERS.keys())
+
+
+def list_writers():
+    """list available writers"""
+    print(WRITERS.keys())
+
 
 def load_file(filename, **keywords):
     """Load data from any supported excel formats
@@ -75,4 +80,4 @@ def get_writer(filename, **keywords):
         else:
             raise NotImplementedError("Cannot open %s" % filename)
     else:
-        raise IOError("cannot handle unknown content")
\ No newline at end of file
+        raise IOError("cannot handle unknown content")
